@@ -81,7 +81,8 @@ class FeedStorageMK4Impl::FeedStorageMK4ImplPrivate
         c4_Storage* tagStorage;
         c4_View tagView;
         bool autoCommit;
-	    bool modified;
+        bool modified;
+        bool taggingEnabled;
         bool convert;
         QString oldArchivePath;
         c4_StringProp pguid, ptitle, pdescription, plink, pcommentsLink, ptag, pEnclosureType, pEnclosureUrl, pcatTerm, pcatScheme, pcatName;
@@ -133,7 +134,8 @@ FeedStorageMK4Impl::FeedStorageMK4Impl(const QString& url, StorageMK4Impl* main)
     d->autoCommit = main->autoCommit();
     d->url = url;
     d->mainStorage = main;
-
+    d->taggingEnabled = main->taggingEnabled();
+    
     QString url2 = url;
 
     if (url.length() > 255)
@@ -146,6 +148,7 @@ FeedStorageMK4Impl::FeedStorageMK4Impl(const QString& url, StorageMK4Impl* main)
     QString t2 = url2;
     QString filePath = main->archivePath() +"/"+ t.replace("/", "_").replace(":", "_");
     d->oldArchivePath = KGlobal::dirs()->saveLocation("data", "akregator/Archive/") + t2.replace("/", "_").replace(":", "_") + ".xml";
+
     d->convert = !QFile::exists(filePath + ".mk4") && QFile::exists(d->oldArchivePath);
     d->storage = new c4_Storage((filePath + ".mk4").local8Bit(), true);
 
@@ -154,22 +157,26 @@ FeedStorageMK4Impl::FeedStorageMK4Impl(const QString& url, StorageMK4Impl* main)
     c4_View hash = d->storage->GetAs("archiveHash[_H:I,_R:I]");
     d->archiveView = d->archiveView.Hash(hash, 1); // hash on guid
 
+    d->tagStorage = 0;
 
-    d->tagStorage = new c4_Storage((filePath + ".mk4___TAGS").local8Bit(), true);
-    d->tagView = d->tagStorage->GetAs("tagIndex[tag:S,taggedArticles[guid:S]]");
-    hash = d->tagStorage->GetAs("archiveHash[_H:I,_R:I]");
-    d->tagView = d->tagView.Hash(hash, 1); // hash on tag
-
-    d->catStorage = new c4_Storage((filePath + ".mk4___CATEGORIES").local8Bit(), true);
-    d->catView = d->catStorage->GetAs("catIndex[catTerm:S,catScheme:S,catName:S,categorizedArticles[guid:S]]");
+    if (d->taggingEnabled)
+    {
+        d->tagStorage = new c4_Storage((filePath + ".mk4___TAGS").local8Bit(), true);
+        d->tagView = d->tagStorage->GetAs("tagIndex[tag:S,taggedArticles[guid:S]]");
+        hash = d->tagStorage->GetAs("archiveHash[_H:I,_R:I]");
+        d->tagView = d->tagView.Hash(hash, 1); // hash on tag
+    }
+    //d->catStorage = new c4_Storage((filePath + ".mk4___CATEGORIES").local8Bit(), true);
+    //d->catView = d->catStorage->GetAs("catIndex[catTerm:S,catScheme:S,catName:S,categorizedArticles[guid:S]]");
 }
 
 
 FeedStorageMK4Impl::~FeedStorageMK4Impl()
 {
     delete d->storage;
-    delete d->tagStorage;
-    delete d->catStorage;
+    if (d->taggingEnabled)
+        delete d->tagStorage;
+//    delete d->catStorage;
     delete d; d = 0;
 }
 
@@ -178,8 +185,9 @@ void FeedStorageMK4Impl::commit()
     if (d->modified)
     {
         d->storage->Commit();
-        d->tagStorage->Commit();
-        d->catStorage->Commit();
+        if (d->taggingEnabled)
+            d->tagStorage->Commit();
+//        d->catStorage->Commit();
     }
     d->modified = false;
 }
@@ -187,8 +195,9 @@ void FeedStorageMK4Impl::commit()
 void FeedStorageMK4Impl::rollback()
 {
     d->storage->Rollback();
-    d->tagStorage->Rollback();
-    d->catStorage->Rollback();
+    if (d->taggingEnabled)
+        d->tagStorage->Rollback();
+//    d->catStorage->Rollback();
 }
 
 void FeedStorageMK4Impl::close()
@@ -234,7 +243,7 @@ QStringList FeedStorageMK4Impl::articles(const QString& tag)
         for (int i = 0; i < size; i++) // fill with guids
             list += QString(d->pguid(d->archiveView.GetAt(i)));
     }
-    else
+    else if (d->taggingEnabled)
     {
         c4_Row tagrow;
         d->ptag(tagrow) = tag.utf8().data();
@@ -255,7 +264,7 @@ QStringList FeedStorageMK4Impl::articles(const QString& tag)
 QStringList FeedStorageMK4Impl::articles(const Category& cat)
 {
     QStringList list;
-
+    /*
     c4_Row catrow;
     d->pcatTerm(catrow) = cat.term.utf8().data();
     d->pcatScheme(catrow) = cat.scheme.utf8().data();
@@ -269,7 +278,7 @@ QStringList FeedStorageMK4Impl::articles(const Category& cat)
         for (int i = 0; i < size; i++)
             list += QString(d->pguid(catView.GetAt(i)));
     }
-
+    */
     return list;
 }
 
@@ -514,12 +523,14 @@ void FeedStorageMK4Impl::setGuidIsPermaLink(const QString& guid, bool isPermaLin
     d->modified = true;
 }
 
-void FeedStorageMK4Impl::addCategory(const QString& guid, const Category& cat)
+void FeedStorageMK4Impl::addCategory(const QString& /*guid*/, const Category& /*cat*/)
 {
+    return;
+    /*
     int findidx = findArticle(guid);
     if (findidx == -1)
         return;
-
+    
     c4_Row row;
     row = d->archiveView.GetAt(findidx);
     c4_View catView = d->pcategories(row);
@@ -565,13 +576,15 @@ void FeedStorageMK4Impl::addCategory(const QString& guid, const Category& cat)
 
         d->modified = true;
     } 
+    */
 }
 
-QValueList<Category> FeedStorageMK4Impl::categories(const QString& guid)
+QValueList<Category> FeedStorageMK4Impl::categories(const QString& /*guid*/)
 {
 
     QValueList<Category> list;
-        
+    return list;
+    /*  
     if (!guid.isNull()) // return categories for an article
     {
         int findidx = findArticle(guid);
@@ -610,11 +623,14 @@ QValueList<Category> FeedStorageMK4Impl::categories(const QString& guid)
         }
     }
     
-    return list;
+    return list;*/
 }
 
 void FeedStorageMK4Impl::addTag(const QString& guid, const QString& tag)
 {
+    if (!d->taggingEnabled)
+        return;
+    
     int findidx = findArticle(guid);
     if (findidx == -1)
         return;
@@ -656,6 +672,9 @@ void FeedStorageMK4Impl::addTag(const QString& guid, const QString& tag)
 
 void FeedStorageMK4Impl::removeTag(const QString& guid, const QString& tag)
 {
+    if (!d->taggingEnabled)
+        return;
+    
     int findidx = findArticle(guid);
     if (findidx == -1)
         return;
@@ -700,6 +719,9 @@ QStringList FeedStorageMK4Impl::tags(const QString& guid)
 {
     QStringList list;
     
+    if (!d->taggingEnabled)
+        return list;
+    
     if (!guid.isNull()) // return tags for an articles
     {
         int findidx = findArticle(guid);
@@ -807,7 +829,8 @@ void FeedStorageMK4Impl::enclosure(const QString& guid, bool& hasEnclosure, QStr
 void FeedStorageMK4Impl::clear()
 {
     d->storage->RemoveAll();
-    d->tagStorage->RemoveAll();
+    if (d->taggingEnabled)
+        d->tagStorage->RemoveAll();
     setUnread(0);
     d->modified = true;
 }
