@@ -1,7 +1,7 @@
 /*******************************************************************
  KNotes -- Notes for the KDE project
 
- Copyright (c) 1997-2004, The KNotes Developers
+ Copyright (c) 1997-2006, The KNotes Developers
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -15,7 +15,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *******************************************************************/
 
 #include <qclipboard.h>
@@ -32,17 +32,21 @@
 #include <kstandarddirs.h>
 #include <kpopupmenu.h>
 #include <khelpmenu.h>
+#include <kfind.h>
+#include <kfinddialog.h>
 #include <kkeydialog.h>
 #include <kglobalaccel.h>
 #include <ksimpleconfig.h>
 #include <kwin.h>
-#include <kextsock.h>
+#include <kbufferedsocket.h>
+#include <kserversocket.h>
 
 #include <libkcal/journal.h>
 #include <libkcal/calendarlocal.h>
 
 #include "knotesapp.h"
 #include "knote.h"
+#include "knotesalarm.h"
 #include "knoteconfigdlg.h"
 #include "knotesglobalconfig.h"
 #include "knoteslegacy.h"
@@ -50,13 +54,14 @@
 
 #include "knotes/resourcemanager.h"
 
+using namespace KNetwork;
+
 
 class KNotesKeyDialog : public KDialogBase
 {
 public:
     KNotesKeyDialog( KGlobalAccel *globals, QWidget *parent, const char* name = 0 )
-        : KDialogBase( parent, name, true, QString::null, Default|Ok|Cancel, Ok )
-//        : KDialogBase( parent, name, true, i18n("Configure Shortcuts"), Default|Ok|Cancel, Ok )
+        : KDialogBase( parent, name, true, i18n("Configure Shortcuts"), Default|Ok|Cancel, Ok )
     {
         m_keyChooser = new KKeyChooser( globals, this );
         setMainWidget( m_keyChooser );
@@ -65,8 +70,7 @@ public:
 
     void insert( KActionCollection *actions )
     {
-        //m_keyChooser->insert( actions, i18n("Note Actions") );
-        m_keyChooser->insert( actions );
+        m_keyChooser->insert( actions, i18n("Note Actions") );
     }
 
     void configure()
@@ -90,7 +94,7 @@ int KNotesApp::KNoteActionList::compareItems( QPtrCollection::Item s1, QPtrColle
 
 KNotesApp::KNotesApp()
     : DCOPObject("KNotesIface"), QLabel( 0, 0, WType_TopLevel ),
-      m_listener( 0 )
+      m_alarm( 0 ), m_listener( 0 ), m_find( 0 ), m_findPos( 0 )
 {
     connect( kapp, SIGNAL(lastWindowClosed()), kapp, SLOT(quit()) );
 
@@ -103,19 +107,24 @@ KNotesApp::KNotesApp()
     setBackgroundMode( X11ParentRelative );
     setPixmap( KSystemTray::loadIcon( "knotes" ) );
 
+    // set the initial style
+    KNote::setStyle( KNotesGlobalConfig::style() );
+
     // create the GUI...
     new KAction( i18n("New Note"), "filenew", 0,
         this, SLOT(newNote()), actionCollection(), "new_note" );
     new KAction( i18n("New Note From Clipboard"), "editpaste", 0,
         this, SLOT(newNoteFromClipboard()), actionCollection(), "new_note_clipboard" );
-//    new KAction( i18n("Show All Notes"), "knotes", 0,
-//        this, SLOT(showAllNotes()), actionCollection(), "show_all_notes" );
-//    new KAction( i18n("Hide All Notes"), "fileclose", 0,
-//        this, SLOT(hideAllNotes()), actionCollection(), "hide_all_notes" );
+    new KAction( i18n("Show All Notes"), "knotes", 0,
+        this, SLOT(showAllNotes()), actionCollection(), "show_all_notes" );
+    new KAction( i18n("Hide All Notes"), "fileclose", 0,
+        this, SLOT(hideAllNotes()), actionCollection(), "hide_all_notes" );
     new KHelpMenu( this, kapp->aboutData(), false, actionCollection() );
 
+    KStdAction::find( this, SLOT(slotOpenFindDialog()), actionCollection() );
     KStdAction::preferences( this, SLOT(slotPreferences()), actionCollection() );
     KStdAction::keyBindings( this, SLOT(slotConfigureAccels()), actionCollection() );
+    //FIXME: no shortcut removing!?
     KStdAction::quit( this, SLOT(slotQuit()), actionCollection() )->setShortcut( 0 );
 
     setXMLFile( instance()->instanceName() + "appui.rc" );
@@ -127,9 +136,15 @@ KNotesApp::KNotesApp()
     m_context_menu = static_cast<KPopupMenu*>(m_guiFactory->container( "knotes_context", this ));
     m_note_menu = static_cast<KPopupMenu*>(m_guiFactory->container( "notes_menu", this ));
 
-    m_noteGUI.setContent(
-        KXMLGUIFactory::readConfigFile( instance()->instanceName() + "ui.rc", instance() )
-    );
+    // get the most recent XML UI file
+    QString xmlFileName = instance()->instanceName() + "ui.rc";
+    QString filter = QString::fromLatin1( instance()->instanceName() + '/' ) + xmlFileName;
+    QStringList fileList = instance()->dirs()->findAllResources( "data", filter ) +
+                           instance()->dirs()->findAllResources( "data", xmlFileName );
+
+    QString doc;
+    KXMLGUIClient::findMostRecentXMLFile( fileList, doc );
+    m_noteGUI.setContent( doc );
 
     // create accels for global shortcuts
     m_globalAccel = new KGlobalAccel( this, "global accel" );
@@ -139,12 +154,12 @@ KNotesApp::KNotesApp()
     m_globalAccel->insert( "global_new_note_clipboard", i18n("New Note From Clipboard"), "",
                            ALT+SHIFT+Key_C, ALT+SHIFT+Key_C,
                            this, SLOT(newNoteFromClipboard()), true, true );
-//    m_globalAccel->insert( "global_hide_all_notes", i18n("Hide All Notes"), "",
-//                           ALT+SHIFT+Key_H, ALT+SHIFT+Key_H ,
-//                           this, SLOT(hideAllNotes()), true, true );
-//    m_globalAccel->insert( "global_show_all_notes", i18n("Show All Notes"), "",
-//                           ALT+SHIFT+Key_S, ALT+SHIFT+Key_S,
-//                           this, SLOT(showAllNotes()), true, true );
+    m_globalAccel->insert( "global_hide_all_notes", i18n("Hide All Notes"), "",
+                           ALT+SHIFT+Key_H, ALT+SHIFT+Key_H ,
+                           this, SLOT(hideAllNotes()), true, true );
+    m_globalAccel->insert( "global_show_all_notes", i18n("Show All Notes"), "",
+                           ALT+SHIFT+Key_S, ALT+SHIFT+Key_S,
+                           this, SLOT(showAllNotes()), true, true );
 
     m_globalAccel->readSettings();
 
@@ -168,7 +183,7 @@ KNotesApp::KNotesApp()
     m_manager->load();
 
     // read the old config files, convert and add them
-    KCal::CalendarLocal calendar;
+    KCal::CalendarLocal calendar( QString::fromLatin1( "UTC" ) );
     if ( KNotesLegacy::convert( &calendar ) )
     {
         KCal::Journal::List notes = calendar.journals();
@@ -179,16 +194,20 @@ KNotesApp::KNotesApp()
         m_manager->save();
     }
 
+    // set up the alarm reminder - do it after loading the notes because this
+    // is used as a check if updateNoteActions has to be called for a new note
+    m_alarm = new KNotesAlarm( m_manager, this );
+
     // create the socket and possibly start listening for connections
-    m_listener = new KExtendedSocket();
-    m_listener->setSocketFlags( KExtendedSocket::passiveSocket | KExtendedSocket::inetSocket );
+    m_listener = new KServerSocket();
+    m_listener->setResolutionEnabled( true );
     connect( m_listener, SIGNAL(readyAccept()), SLOT(acceptConnection()) );
     updateNetworkListener();
 
     if ( m_noteList.count() == 0 && !kapp->isRestored() )
         newNote();
 
-    updateNoteActions();  // in case there is no note yet
+    updateNoteActions();
 }
 
 KNotesApp::~KNotesApp()
@@ -414,6 +433,44 @@ void KNotesApp::slotWalkThroughNotes()
         }
 }
 
+void KNotesApp::slotOpenFindDialog()
+{
+    KFindDialog findDia( this, "find_dialog" );
+    findDia.setHasSelection( false );
+    findDia.setHasCursor( false );
+    findDia.setSupportsBackwardsFind( false );
+
+    if ( findDia.exec() != QDialog::Accepted )
+        return;
+
+    delete m_findPos;
+    m_findPos = new QDictIterator<KNote>( m_noteList );
+
+    // this could be in an own method if searching without a dialog should be possible
+    delete m_find;
+    m_find = new KFind( findDia.pattern(), findDia.options(), this );
+
+    slotFindNext();
+}
+
+void KNotesApp::slotFindNext()
+{
+    if ( **m_findPos )
+    {
+        KNote *note = **m_findPos;
+        ++*m_findPos;
+        note->find( m_find->pattern(), m_find->options() );
+    }
+    else
+    {
+        m_find->displayFinalDialog();
+        delete m_find;
+        m_find = 0;
+        delete m_findPos;
+        m_findPos = 0;
+    }
+}
+
 void KNotesApp::slotPreferences()
 {
     // reuse the dialog if possible
@@ -424,6 +481,7 @@ void KNotesApp::slotPreferences()
     KNoteConfigDlg *dialog = new KNoteConfigDlg( 0, i18n("Settings"), this,
                                                  "KNotes Settings" );
     connect( dialog, SIGNAL(settingsChanged()), this, SLOT(updateNetworkListener()) );
+    connect( dialog, SIGNAL(settingsChanged()), this, SLOT(updateStyle()) );
     dialog->show();
 }
 
@@ -463,9 +521,7 @@ void KNotesApp::slotConfigureAccels()
 void KNotesApp::slotNoteKilled( KCal::Journal *journal )
 {
     m_manager->deleteNote( journal );
-
     saveNotes();
-    updateNoteActions();
 }
 
 void KNotesApp::slotQuit()
@@ -503,8 +559,11 @@ void KNotesApp::createNote( KCal::Journal *journal )
     connect( newNote, SIGNAL(sigNameChanged()), SLOT(updateNoteActions()) );
     connect( newNote, SIGNAL(sigDataChanged()), SLOT(saveNotes()) );
     connect( newNote, SIGNAL(sigColorChanged()), SLOT(updateNoteActions()) );
+    connect( newNote, SIGNAL(sigFindFinished()), SLOT(slotFindNext()) );
 
-    updateNoteActions();
+    // don't call this during startup for each and every loaded note
+    if ( m_alarm )
+        updateNoteActions();
 }
 
 void KNotesApp::killNote( KCal::Journal *journal )
@@ -517,15 +576,18 @@ void KNotesApp::killNote( KCal::Journal *journal )
 void KNotesApp::acceptConnection()
 {
     // Accept the connection and make KNotesNetworkReceiver do the job
-    KExtendedSocket *s;
-    m_listener->accept( s );
-    KNotesNetworkReceiver *recv = new KNotesNetworkReceiver( s );
-    connect( recv, SIGNAL(sigNoteReceived( const QString &, const QString & )),
-             this, SLOT(newNote( const QString &, const QString & )) );
+    KBufferedSocket *s = static_cast<KBufferedSocket *>(m_listener->accept());
+    if ( s )
+    {
+        KNotesNetworkReceiver *recv = new KNotesNetworkReceiver( s );
+        connect( recv, SIGNAL(sigNoteReceived( const QString &, const QString & )),
+                 this, SLOT(newNote( const QString &, const QString & )) );
+    }
 }
 
 void KNotesApp::saveNotes()
 {
+    KNotesGlobalConfig::writeConfig();
     m_manager->save();
 }
 
@@ -603,13 +665,23 @@ void KNotesApp::updateGlobalAccels()
 
 void KNotesApp::updateNetworkListener()
 {
-    m_listener->reset();
+    m_listener->close();
 
     if ( KNotesGlobalConfig::receiveNotes() )
     {
-        m_listener->setPort( KNotesGlobalConfig::port() );
+        m_listener->setAddress( QString::number( KNotesGlobalConfig::port() ) );
+        m_listener->bind();
         m_listener->listen();
     }
 }
 
+void KNotesApp::updateStyle()
+{
+    KNote::setStyle( KNotesGlobalConfig::style() );
+
+    QDictIterator<KNote> it( m_noteList );
+    for ( ; it.current(); ++it )
+        QApplication::postEvent( *it, new QEvent( QEvent::LayoutHint ) );
+}
+
 #include "knotesapp.moc"
