@@ -1,7 +1,7 @@
 /*
    This file is part of the KDE project
    Copyright (C) 2002-2003 Daniel Molkentin <molkentin@kde.org>
-   Copyright (C) 2004 Michael Brade <brade@kde.org>
+   Copyright (C) 2004-2006 Michael Brade <brade@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -49,20 +49,21 @@ KNotesPart::KNotesPart( QObject *parent, const char *name )
   setInstance( new KInstance( "knotes" ) );
 
   // create the actions
-  new KAction( i18n( "&New..." ), "knotes", CTRL+Key_N, this, SLOT( newNote() ),
+  new KAction( i18n( "&New" ), "knotes", CTRL+Key_N, this, SLOT( newNote() ),
                actionCollection(), "file_new" );
-  new KAction( i18n( "Rename" ), "text", this, SLOT( renameNote() ),
+  new KAction( i18n( "Rename..." ), "text", this, SLOT( renameNote() ),
                actionCollection(), "edit_rename" );
   new KAction( i18n( "Delete" ), "editdelete", Key_Delete, this, SLOT( killSelectedNotes() ),
                actionCollection(), "edit_delete" );
 
-  // TODO styleguide: s/New.../New/, s/Rename/Rename.../
   // TODO icons: s/editdelete/knotes_delete/ or the other way round in knotes
 
   // set the view up
   mNotesView->setSelectionMode( QIconView::Extended );
   mNotesView->setItemsMovable( false );
   mNotesView->setResizeMode( QIconView::Adjust );
+  mNotesView->setAutoArrange( true );
+  mNotesView->setSorting( true );
 
   connect( mNotesView, SIGNAL( executed( QIconViewItem* ) ),
            this, SLOT( editNote( QIconViewItem* ) ) );
@@ -150,12 +151,13 @@ QString KNotesPart::newNote( const QString& name, const QString& text )
     }
   }
 
+  mManager->addNewNote( journal );
+  mManager->save();
+
   KNotesIconViewItem *note = mNoteList[ journal->uid() ];
   mNotesView->ensureItemVisible( note );
   mNotesView->setCurrentItem( note );
 
-  mManager->addNewNote( journal );
-  mManager->save();
   return journal->uid();
 }
 
@@ -177,7 +179,8 @@ void KNotesPart::killNote( const QString& id, bool force )
    if ( note && !force && KMessageBox::warningContinueCancelList( mNotesView,
         i18n( "Do you really want to delete this note?" ),
         mNoteList[ id ]->text(), i18n( "Confirm Delete" ),
-        KStdGuiItem::del() ) == KMessageBox::Continue ) {
+        KStdGuiItem::del() ) == KMessageBox::Continue ) 
+   {
      mManager->deleteNote( mNoteList[id]->journal() );
      mManager->save();
    }
@@ -328,11 +331,13 @@ void KNotesPart::editNote( QIconViewItem *item )
     mNoteEditDlg = new KNoteEditDlg( widget() );
 
   KCal::Journal *journal = static_cast<KNotesIconViewItem *>( item )->journal();
+
+  mNoteEditDlg->setRichText( journal->customProperty( "KNotes", "RichText" ) == "true" );
   mNoteEditDlg->setTitle( journal->summary() );
   mNoteEditDlg->setText( journal->description() );
 
   if ( mNoteEditDlg->exec() == QDialog::Accepted ) {
-    journal->setSummary( mNoteEditDlg->title() );
+    item->setText( mNoteEditDlg->title() );
     journal->setDescription( mNoteEditDlg->text() );
     mManager->save();
   }
