@@ -2,6 +2,7 @@
     This file is part of KOrganizer.
 
     Copyright (c) 2000,2001,2003 Cornelius Schumacher <schumacher@kde.org>
+    Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,7 +16,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -53,8 +54,8 @@ struct MultiItemInfo
   to be used for dragging and resizing. That means it has to be installed as
   eventfiler for its children, if it has children, and it has to pass mouse
   events from the cildren to itself. See eventFilter().
-  
-  
+
+
   Some comments on the movement of multi-day items:
   Basically, the agenda items are arranged in two implicit double-linked lists.
   The mMultiItemInfo works like before to describe the currently viewed
@@ -74,7 +75,7 @@ class KOAgendaItem : public QWidget, public KOrg::CellItem
 {
     Q_OBJECT
   public:
-    KOAgendaItem(Incidence *incidence, QDate qd, QWidget *parent, const char *name=0,
+    KOAgendaItem(Incidence *incidence, const QDate &qd, QWidget *parent, const char *name=0,
                  WFlags f=0 );
 
     int cellXLeft() const { return mCellXLeft; }
@@ -115,13 +116,15 @@ class KOAgendaItem : public QWidget, public KOrg::CellItem
     KOAgendaItem *prevMultiItem() const { return (mMultiItemInfo)?(mMultiItemInfo->mPrevMultiItem):0; }
     KOAgendaItem *nextMultiItem() const { return (mMultiItemInfo)?(mMultiItemInfo->mNextMultiItem):0; }
     KOAgendaItem *lastMultiItem() const { return (mMultiItemInfo)?(mMultiItemInfo->mLastMultiItem):0; }
-    
+
+    bool dissociateFromMultiItem();
+
     bool setIncidence( Incidence * );
     Incidence *incidence() const { return mIncidence; }
     QDate itemDate() { return mDate; }
 
     /** Update the date of this item's occurrence (not in the event) */
-    void setItemDate(QDate qd);
+    void setItemDate( const QDate &qd );
 
     void setText ( const QString & text ) { mLabelText = text; }
     QString text () { return mLabelText; }
@@ -131,11 +134,13 @@ class KOAgendaItem : public QWidget, public KOrg::CellItem
     QPtrList<KOAgendaItem> conflictItems();
     void setConflictItems(QPtrList<KOAgendaItem>);
     void addConflictItem(KOAgendaItem *ci);
-    
+
     QString label() const;
 
     bool overlaps( KOrg::CellItem * ) const;
 
+    void setResourceColor( const QColor& color ) { mResourceColor = color; }
+    QColor resourceColor() {return mResourceColor;}
   signals:
     void removeAgendaItem( KOAgendaItem* );
     void showAgendaItem( KOAgendaItem* );
@@ -143,7 +148,7 @@ class KOAgendaItem : public QWidget, public KOrg::CellItem
   public slots:
     void updateIcons();
     void select(bool=true);
-    void addAttendee(QString);
+    void addAttendee( const QString & );
 
   protected:
     void dragEnterEvent(QDragEnterEvent *e);
@@ -151,6 +156,10 @@ class KOAgendaItem : public QWidget, public KOrg::CellItem
     void paintEvent(QPaintEvent *e);
     void paintFrame(QPainter *p, const QColor &color);
     void paintTodoIcon(QPainter *p, int &x, int ft);
+
+    // paint all visible icons
+    void paintIcons(QPainter *p, int &x, int ft);
+
     /** private movement functions. startMove needs to be called of only one of
      *  the multitems. it will then loop through the whole series using
      *  startMovePrivate. Same for resetMove and endMove */
@@ -169,19 +178,29 @@ class KOAgendaItem : public QWidget, public KOrg::CellItem
     QDate mDate; //date this events occurs (for recurrence)
     QString mLabelText;
     bool mIconAlarm, mIconRecur, mIconReadonly;
-    bool mIconReply, mIconGroup, mIconOrganizer;
+    bool mIconReply, mIconGroup, mIconGroupTentative;
+    bool mIconOrganizer;
 
     // Multi item pointers
     MultiItemInfo* mMultiItemInfo;
   protected:
     // Variables to remember start position
     MultiItemInfo* mStartMoveInfo;
-
+    //Color of the resource
+    QColor mResourceColor;
   private:
     static QToolTipGroup *mToolTipGroup;
 
     bool mSelected;
     QPtrList<KOAgendaItem> mConflictItems;
+
+    static QPixmap *alarmPxmp;
+    static QPixmap *recurPxmp;
+    static QPixmap *readonlyPxmp;
+    static QPixmap *replyPxmp;
+    static QPixmap *groupPxmp;
+    static QPixmap *groupPxmpTentative;
+    static QPixmap *organizerPxmp;
 };
 
 #endif
